@@ -52,7 +52,7 @@ options.eureka_enable = False
 options.eureka_server = ""
 options.eureka_instance_name = ""
 options.eureka_instance_ip = ""
-options.eureka_instance_port = 8901
+options.eureka_instance_port = None
 options.rms_register_enable = False
 options.rms_register_server = "http://127.0.0.1:8918"
 options.running_env = "local"
